Name:           ocaml-ocplib-endian
Version:        1.0
Release:        %mkrel 4
Summary:        Functions to read/write int16/32/64 from strings, bigarrays
Group:          Development/OCaml

%global libname ocplib-endian

# License is LGPL 2.1 with standard OCaml exceptions
License:        LGPLv2+ with exceptions
URL:            https://github.com/OCamlPro/ocplib-endian
Source0:        https://github.com/OCamlPro/ocplib-endian/archive/%{version}/ocplib-endian-%{version}.tar.gz

BuildRequires:  ocaml
BuildRequires:  ocaml-findlib
BuildRequires:  ocaml-cppo

BuildRequires:  ocaml-ocamlbuild-devel
# for ocamldoc:
BuildRequires:  ocaml-compiler

%description
Optimised functions to read and write int16/32/64 from strings,
bytes and bigarrays, based on primitives added in version 4.01.

The library implements three modules:

EndianString works directly on strings, and provides submodules
BigEndian and LittleEndian, with their unsafe counter-parts;
EndianBytes works directly on bytes, and provides submodules
BigEndian and LittleEndian, with their unsafe counter-parts;
EndianBigstring works on bigstrings (Bigarrays of chars),
and provides submodules BigEndian and LittleEndian, with their
unsafe counter-parts;

%package        devel
Summary:        Development files for %{name}
Requires:       %{name}%{?_isa} = %{version}-%{release}

%description    devel
The %{name}-devel package contains libraries and
signature files for developing applications that use %{name}.

%prep
%autosetup -n %{libname}-%{version}

%build
ocaml setup.ml -configure --enable-tests
%make_build build

%install
export OCAMLFIND_DESTDIR=%{buildroot}%{_libdir}/ocaml
mkdir -p $OCAMLFIND_DESTDIR
make install DESTDIR=%{buildroot}

%check
# Tests seem to fail on s390x (maybe all big endian architectures).
# See https://github.com/OCamlPro/ocplib-endian/issues/20
%ifnarch s390x
make test
%endif

%files
%license COPYING.txt
%doc README.md CHANGES.md
%{_libdir}/ocaml/%{libname}
%ifarch %{ocaml_native_compiler}
%exclude %{_libdir}/ocaml/%{libname}/*.a
%exclude %{_libdir}/ocaml/%{libname}/*.cmxa
%exclude %{_libdir}/ocaml/%{libname}/*.cmx
%endif
%exclude %{_libdir}/ocaml/%{libname}/*.mli


%files devel
%ifarch %{ocaml_native_compiler}
%{_libdir}/ocaml/%{libname}/*.a
%{_libdir}/ocaml/%{libname}/*.cmxa
%{_libdir}/ocaml/%{libname}/*.cmx
%endif
%{_libdir}/ocaml/%{libname}/*.mli



%changelog
* Sun Jan 10 2021 pterjan <pterjan> 1.0-4.mga8
+ Revision: 1670292
- Rebuild to generate ocamlx provides

* Fri Feb 28 2020 umeabot <umeabot> 1.0-3.mga8
+ Revision: 1551585
- Rebuild for ocaml 4.10.0 final

* Thu Feb 20 2020 umeabot <umeabot> 1.0-2.mga8
+ Revision: 1545145
- Mageia 8 Mass Rebuild

* Mon Jan 27 2020 tv <tv> 1.0-1.mga8
+ Revision: 1484097
- new release + reintroduce for ocaml-4.10
- rebuild for new ocaml

* Mon Sep 26 2016 pterjan <pterjan> 0.4-7.mga6
+ Revision: 1056428
- Rebuild for fix in ocaml

* Wed Feb 17 2016 umeabot <umeabot> 0.4-6.mga6
+ Revision: 963857
- Mageia 6 Mass Rebuild

* Wed Oct 15 2014 umeabot <umeabot> 0.4-5.mga5
+ Revision: 748093
- Second Mageia 5 Mass Rebuild

* Tue Sep 16 2014 umeabot <umeabot> 0.4-4.mga5
+ Revision: 683077
- Mageia 5 Mass Rebuild

* Sat Oct 19 2013 umeabot <umeabot> 0.4-3.mga4
+ Revision: 533932
- Mageia 4 Mass Rebuild

* Sun Sep 08 2013 blue_prawn <blue_prawn> 0.4-2.mga4
+ Revision: 475822
- provide license file

* Sun Sep 08 2013 blue_prawn <blue_prawn> 0.4-1.mga4
+ Revision: 475814
- updated to last version 0.4
- providing the generated api doc

* Sun Jan 13 2013 umeabot <umeabot> 0.3-2.mga3
+ Revision: 361529
- Mass Rebuild - https://wiki.mageia.org/en/Feature:Mageia3MassRebuild

* Fri Jan 04 2013 malo <malo> 0.3-1.mga3
+ Revision: 338458
- imported package ocaml-ocplib-endian

